@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2008 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Produce and handle the member options."""
 
@@ -98,9 +99,11 @@ def main():
         user = cgidata.getvalue('email')
         if not user:
             # If we're coming from the listinfo page and we left the email
-            # address field blank, it's not an error.  listinfo.html names the
-            # button UserOptions; we can use that as the descriminator.
-            if not cgidata.getvalue('UserOptions'):
+            # address field blank, it's not an error.  Likewise if we're
+            # coming from anywhere else. Only issue the error if we came
+            # via one of our buttons.
+            if (cgidata.getvalue('login') or cgidata.getvalue('login-unsub')
+                    or cgidata.getvalue('login-remind')):
                 doc.addError(_('No address given'))
             loginpage(mlist, doc, None, language)
             print doc.Format()
@@ -218,10 +221,23 @@ def main():
         print doc.Format()
         return
 
-    # Authenticate, possibly using the password supplied in the login page
+    # Get the password from the form.
     password = cgidata.getvalue('password', '').strip()
-    if not mlist.WebAuthenticate((mm_cfg.AuthUser,
-                                  mm_cfg.AuthListAdmin,
+    # Check authentication.  We need to know if the credentials match the user
+    # or the site admin, because they are the only ones who are allowed to
+    # change things globally.  Specifically, the list admin may not change
+    # values globally.
+    if mm_cfg.ALLOW_SITE_ADMIN_COOKIES:
+        user_or_siteadmin_context = (mm_cfg.AuthUser, mm_cfg.AuthSiteAdmin)
+    else:
+        # Site and list admins are treated equal so that list admin can pass
+        # site admin test. :-(
+        user_or_siteadmin_context = (mm_cfg.AuthUser,)
+    is_user_or_siteadmin = mlist.WebAuthenticate(
+        user_or_siteadmin_context, password, user)
+    # Authenticate, possibly using the password supplied in the login page
+    if not is_user_or_siteadmin and \
+       not mlist.WebAuthenticate((mm_cfg.AuthListAdmin,
                                   mm_cfg.AuthSiteAdmin),
                                  password, user):
         # Not authenticated, so throw up the login page again.  If they tried
@@ -259,6 +275,13 @@ def main():
         return
 
     if cgidata.has_key('othersubs'):
+        # Only the user or site administrator can view all subscriptions.
+        if not is_user_or_siteadmin:
+            doc.addError(_("""The list administrator may not view the other
+            subscriptions for this user."""), _('Note: '))
+            options_page(mlist, doc, user, cpuser, userlang)
+            print doc.Format()
+            return
         hostname = mlist.host_name
         title = _('List subscriptions for %(safeuser)s on %(hostname)s')
         doc.SetTitle(title)
@@ -291,9 +314,15 @@ def main():
         oldname = mlist.getMemberName(user)
         set_address = set_membername = 0
 
-        # See if the user wants to change their email address globally
+        # See if the user wants to change their email address globally.  The
+        # list admin is /not/ allowed to make global changes.
         globally = cgidata.getvalue('changeaddr-globally')
-
+        if globally and not is_user_or_siteadmin:
+            doc.addError(_("""The list administrator may not change the names
+            or addresses for this user's other subscriptions.  However, the
+            subscription for this mailing list has been changed."""),
+                         _('Note: '))
+            globally = False
         # We will change the member's name under the following conditions:
         # - membername has a value
         # - membername has no value, but they /used/ to have a membername
@@ -372,6 +401,11 @@ address.  Upon confirmation, any other mailing list containing the address
                 msg = _('Illegal email address provided')
             except Errors.MMAlreadyAMember:
                 msg = _('%(newaddr)s is already a member of the list.')
+            except Errors.MembershipIsBanned:
+                owneraddr = mlist.GetOwnerEmail()
+                msg = _("""%(newaddr)s is banned from this list.  If you
+                      think this restriction is erroneous, please contact
+                      the list owners at %(owneraddr)s.""")
 
         if set_membername:
             mlist.Lock()
@@ -387,6 +421,14 @@ address.  Upon confirmation, any other mailing list containing the address
         return
 
     if cgidata.has_key('changepw'):
+        # Is this list admin and is list admin allowed to change passwords.
+        if not (is_user_or_siteadmin
+                or mm_cfg.OWNERS_CAN_CHANGE_MEMBER_PASSWORDS):
+            doc.addError(_("""The list administrator may not change the
+                    password for a user."""))
+            options_page(mlist, doc, user, cpuser, userlang)
+            print doc.Format()
+            return
         newpw = cgidata.getvalue('newpw')
         confirmpw = cgidata.getvalue('confpw')
         if not newpw or not confirmpw:
@@ -400,9 +442,19 @@ address.  Upon confirmation, any other mailing list containing the address
             print doc.Format()
             return
 
-        # See if the user wants to change their passwords globally
+        # See if the user wants to change their passwords globally, however
+        # the list admin is /not/ allowed to change passwords globally.
+        pw_globally = cgidata.getvalue('pw-globally')
+        if pw_globally and not is_user_or_siteadmin:
+            doc.addError(_("""The list administrator may not change the
+            password for this user's other subscriptions.  However, the
+            password for this mailing list has been changed."""),
+                         _('Note: '))
+            pw_globally = False
+
         mlists = [mlist]
-        if cgidata.getvalue('pw-globally'):
+
+        if pw_globally:
             mlists.extend(lists_of_member(mlist, user))
 
         for gmlist in mlists:
@@ -606,9 +658,17 @@ address.  Upon confirmation, any other mailing list containing the address
                     globalopts.mime = newval
                     break
 
+        # Change options globally, but only if this is the user or site admin,
+        # /not/ if this is the list admin.
         if globalopts:
-            for gmlist in lists_of_member(mlist, user):
-                global_options(gmlist, user, globalopts)
+            if not is_user_or_siteadmin:
+                doc.addError(_("""The list administrator may not change the
+                options for this user's other subscriptions.  However the
+                options for this mailing list subscription has been
+                changed."""), _('Note: '))
+            else:
+                for gmlist in lists_of_member(mlist, user):
+                    global_options(gmlist, user, globalopts)
 
         # Now print the results
         if cantdigest:
@@ -652,7 +712,7 @@ def options_page(mlist, doc, user, cpuser, userlang, message=''):
 
     fullname = Utils.uncanonstr(mlist.getMemberName(user), userlang)
     if fullname:
-        presentable_user += ', %s' % fullname
+        presentable_user += ', %s' % Utils.websafe(fullname)
 
     # Do replacements
     replacements = mlist.GetStandardReplacements(userlang)
@@ -747,6 +807,8 @@ def options_page(mlist, doc, user, cpuser, userlang, message=''):
     if mlist.topics:
         table = Table(border="0")
         for name, pattern, description, emptyflag in mlist.topics:
+            if emptyflag:
+                continue
             quotedname = urllib.quote_plus(name)
             details = Link(mlist.GetScriptURL('options') +
                            '/%s/?VARHELP=%s' % (user, quotedname),
@@ -809,6 +871,7 @@ def loginpage(mlist, doc, user, lang):
     # Preamble
     # Set up the login page
     form = Form(actionurl)
+    form.AddItem(Hidden('language', lang))
     table = Table(width='100%', border=0, cellspacing=4, cellpadding=5)
     table.AddRow([_("""In order to change your membership option, you must
     first log in by giving your %(extra)smembership password in the section
